#!/usr/bin/env python3


# ===========================================================================================
# Einbinden der Bibliotheken (Module)
# ===========================================================================================

# Modul, das zur Herstellung von Grafiken verwendet wird, siehe https://matplotlib.org
from matplotlib import pyplot as plt

# Die Bibliothek pandas (von PANel DAta) ist darauf spezialisiert Paneldaten zu verarbeiten,
# also zweidimensionale Tabellen (häufig Zeitreihen).
# In diesem Programm wird von dieser Bibliothek aber nur der CSV-Reader verwendet 
# siehe: https://pandas.pydata.org
import pandas as pd


# ===========================================================================================
# Daten einlesen und aufbereiten
# ===========================================================================================

# Wo stehen die Daten?
datasource = 'Daten/bitcoin.csv'

# Immer wichtig zu wissen: Was steht das in den Daten?
#
# In der Liste stehen Bitcoin-Schlusskurse von ein paar Tagen im Mai 2019
#
# Date,Open,High,Low,Close,Adj Close,Volume
# 2019-05-18,7266.080078,8281.660156,7257.259766,8193.139648,8193.139648,723011166
# 2019-05-19,8193.139648,8193.139648,7591.850098,7998.290039,7998.290039,637617163
# 2019-05-20,7998.290039,8102.319824,7807.770020,7947.930176,7947.930176,357803946
# 2019-05-21,7947.930176,8033.759766,7533.660156,7626.890137,7626.890137,424501866
# 2019-05-22,7626.890137,7971.259766,7478.740234,7876.500000,7876.500000,386766321

# Einlesen mit dem CSV-Reader von Pandas
data = pd.read_csv(datasource)

# Das Datum muss extra aufbereitet werden
data['Date'] = pd.to_datetime(data['Date'])
data.sort_values('Date', inplace=True)

# Auswählen der zu verarbeitenden Spalten
price_date = data['Date']
price_close = data['Close']


# ===========================================================================================
# Erstellen des Zeitreihendiagramms
# ===========================================================================================

### Style
# plt.style.use("ggplot")
plt.style.use("seaborn")
# plt.style.use("fivethirtyeight")

# Das Zeitreiendiagramm
plt.plot_date(price_date, price_close, linestyle="solid")

# datum formatieren
plt.gcf().autofmt_xdate()

# Titel
plt.title('Bitcoin Preise')

# Achsenbeschriftung
plt.xlabel('Datum')
plt.ylabel('Schlusskurs')

# Layout-Variation
plt.tight_layout()

# Als Datei speichern
# plt.savefig("MatPlot.png")

# Als interaktive Grafik anzeigen
plt.show()
