#!/usr/bin/env python3


# ===========================================================================================
# Einbinden der Bibliotheken (Module)
# ===========================================================================================

# Modul, das zur Herstellung von Grafiken verwendet wird, siehe https://matplotlib.org
from matplotlib import pyplot as plt

# Die Bibliothek pandas (von PANel DAta) ist darauf spezialisiert Paneldaten zu verarbeiten,
# also zweidimensionale Tabellen (häufig Zeitreihen).
# In diesem Programm wird von dieser Bibliothek aber nur der CSV-Reader verwendet 
# siehe: https://pandas.pydata.org
import pandas as pd


# =========================================================================================== 
# Daten einlesen und aufbereiten
# =========================================================================================== 

# Wo stehen die Daten?
datasource = 'Daten/salery_per_age.csv'

# Immer wichtig zu wissen: Was steht das in den Daten?
#
# Gehälter von Softwareentwicklern pro Alter. Gemittelt über alle Sprachen,
# nur Python-Entwickler und nur Javascript-Entwickler
#
# die ersten Zeilen der Datei sehen so aus:
#
# Age,All_Devs,Python,JavaScript
# 18,17784,20046,16446
# 19,16500,17100,16791
# 20,18012,20000,18942
# 21,20628,24744,21780

# Einlesen mit dem CSV-Reader von Pandas
data = pd.read_csv(datasource)

# Daten für die X-Achse: Alter
ages = data['Age']

# Die Werte aus den drei Gehalts-Spalten
all_salaries = data['All_Devs']
py_salaries  = data['Python']
js_salaries  = data['JavaScript']

# ----------------------------------------------
# Auswahl der Sprache
# ----------------------------------------------

# Python
xx_salaries = py_salaries
xx_label    = 'Python'

# JavaScript
# xx_salaries = js_salaries
# xx_label    = 'JavaScript'



# ===========================================================================================
# Erstellen des Liniendiagramme und der bedingten Flächendiagramme
# ===========================================================================================


# ----------------------------------------------
# Liniendiagramme
# ----------------------------------------------

# Gestrichelte Linie für Mittelwerte über alle Sprachen
plt.plot(ages, all_salaries, color = '#444444', linestyle = '--', label = 'Alle Entwickler')

# Durchgezogene Linie für die Gehälter in der gewählten Sprache
plt.plot(ages, xx_salaries, label = xx_label)


# ----------------------------------------------
# bedingte Flächendiagramme
# ----------------------------------------------

# grüne Flächen für die Teile, wo man mehr als der Durchschnitt verdient
plt.fill_between(ages, xx_salaries, all_salaries, 
	where = (xx_salaries > all_salaries),
	interpolate = True,
	color = 'green',
	alpha = 0.25,
	label = "darüber")

# rote Flächen für die Teile, wo man weniger verdient
plt.fill_between(ages, xx_salaries, all_salaries, 
	where = (xx_salaries <=  all_salaries),
	interpolate = True,
	color = 'red',
	alpha = 0.25,
	label = "darunter")


# Ein Feld für die Legende einblenden
plt.legend()

# Achsenbeschriftung
plt.xlabel('Alter')
plt.ylabel('mittleres Gehalt (USD)')

# Titel
plt.title('Durchschnittsgehalt pro Alter')

# Layout variieren
plt.tight_layout() # schmälere Seitenränder

# Als Datei speichern
# plt.savefig("MatPlot.png")

# Als interaktive Grafik anzeigen
plt.show()
