#!/usr/bin/env python3


# ===========================================================================================
# Einbinden der Bibliotheken (Module)
# ===========================================================================================

# Allgemeines Modul für nummerische Berechnungen, siehe https://numpy.org
import numpy as np

# Modul, das zur Herstellung von Grafiken verwendet wird, siehe https://matplotlib.org
from matplotlib import pyplot as plt

# Die Bibliothek pandas (von PANel DAta) ist darauf spezialisiert Paneldaten zu verarbeiten,
# also zweidimensionale Tabellen (häufig Zeitreihen).
# In diesem Programm wird von dieser Bibliothek aber nur der CSV-Reader verwendet 
# siehe: https://pandas.pydata.org
import pandas as pd


# ===========================================================================================
# Daten einlesen und aufbereiten
# ===========================================================================================

# Wo stehen die Daten?
datasource = 'Daten/ages.csv'

# Immer wichtig zu wissen: Was steht das in den Daten?
#
# Es wurden Programmierer befragt, mit welchen Sprachen sie schon gearbeitete haben
# 87570 Programmierer haben gültige Antworten abgegeben.
# In dieser Datei steht nur das Alter der jeweiligen Auskunftsperson:
#
# Responder_id,Age
# 1,14
# 2,19
# 3,28
# 4,22
# 5,30

# Einlesen mit dem CSV-Reader von Pandas
data = pd.read_csv(datasource)

# Die Responder_id interessiert uns nicht, wir haben nur Interesse am Alter
ages = data['Age']



# ===========================================================================================
# Erstellen des Histogramms
# ===========================================================================================

### Style
# plt.style.use("ggplot")
# plt.style.use("seaborn")
plt.style.use("fivethirtyeight")

# Die Grenzen der Intervalle in denen wir die Datenzeilen pro Altersgruppe sammeln
# Hier werden lauter gleich breite Intervalle zwischen 0 und 120 erzeugt (Breite = 5)
bins = np.arange(0,120,5)

# Das Histogramm mit logarithmischer Darstellung der X-Achse
plt.hist(ages, bins = bins, edgecolor = "black", log = True)

# Das Median-Alter sollte man "im echten Leben" nicht fix codieren, sondern ausrechnen
# In diesem Programm geht es aber nur um die Darstellungsart, daher wird dieser Wert hier
# direkt im Programmcode festgeschrieben
median_age = 29

# Farbe für die Median-Linie
color = '#ff8f30'

# eine vertikale Linie um den Median darzustellen
plt.axvline(median_age, color = color, label = "Median", linewidth = 2)

# Ein Feld für die Legende einblenden
plt.legend()

# Achsenbeschriftung
plt.xlabel('Alter')
plt.ylabel('Anzahl der Personen')

# Titel
plt.title("Alter von Softwareentwicklern")

# Layout-Variation
plt.tight_layout()

# Als Datei speichern
# plt.savefig("MatPlot.png")

# Als interaktive Grafik anzeigen
plt.show()
