#!/usr/bin/env python3


# ===========================================================================================
# Einbinden der Bibliotheken (Module)
# ===========================================================================================

# Allgemeines Modul für nummerische Berechnungen, siehe https://numpy.org
import numpy as np

# Modul, das zur Herstellung von Grafiken verwendet wird, siehe https://matplotlib.org
from matplotlib import pyplot as plt

# Die Bibliothek pandas (von PANel DAta) ist darauf spezialisiert Paneldaten zu verarbeiten,
# also zweidimensionale Tabellen (häufig Zeitreihen).
# In diesem Programm wird von dieser Bibliothek aber nur der CSV-Reader verwendet 
# siehe: https://pandas.pydata.org
import pandas as pd


# ===========================================================================================
# Daten einlesen und aufbereiten
# ===========================================================================================

# Wo stehen die Daten?
datasource = 'Daten/zufallswerte.csv'

# Die hier eingelesenen Daten sind Zufallszahlen, die von einem Zufallszahlengenerator
# erzeugt worden sind.
#
# werte
# 2.843657512
# 7.236355438
# 7.560153614
# 7.129334388
# 6.183812281


# Einlesen mit dem CSV-Reader von Pandas
data = pd.read_csv(datasource)

# Die Responder_id interessiert uns nicht, wir haben nur Interesse am Alter
werte = data['werte']


# ===========================================================================================
# Erstellen des Histogramms
# ===========================================================================================

### Style
# plt.style.use("ggplot")
# plt.style.use("seaborn")
plt.style.use("fivethirtyeight")

# Die Grenzen der Intervalle in denen wir die Datenzeilen pro Altersgruppe sammeln
# Hier werden diese Grenzen manuell vorgegeben
bins = [0, 2, 4, 5, 6, 6.2, 6.4, 6.6, 6.8, 7, 7.2, 7.4, 7.6, 7.8, 8, 9]

# Das Histogramm
plt.hist(werte, bins = bins, edgecolor = "black")

# Hier mal zur Abwechslung ohne Legende
# plt.legend()

# Achsenbeschriftung
plt.xlabel('Wert')
plt.ylabel('Anzahl')

# Titel
plt.title("Histogramm mit variablen Intervallbreiten")

# Layout-Variation
plt.tight_layout()

# Als Datei speichern
# plt.savefig("MatPlot.png")

# Als interaktive Grafik anzeigen
plt.show()
