#!/usr/bin/env python3


# ===========================================================================================
# Einbinden der Bibliotheken (Module)
# ===========================================================================================

# Modul, das zur Herstellung von Grafiken verwendet wird, siehe https://matplotlib.org
from matplotlib import pyplot as plt

# Die Bibliothek pandas (von PANel DAta) ist darauf spezialisiert Paneldaten zu verarbeiten,
# also zweidimensionale Tabellen (häufig Zeitreihen).
# In diesem Programm wird von dieser Bibliothek aber nur der CSV-Reader verwendet 
# siehe: https://pandas.pydata.org
import pandas as pd


# =========================================================================================== 
# Daten einlesen und aufbereiten
# =========================================================================================== 

# Wo stehen die Daten?
datasource = 'Daten/YouTube.csv'

# Immer wichtig zu wissen: Was steht das in den Daten?
#
# In der Liste stehen Daten der meistgesehenen YouTube-Videos (Mai 2019).
# Die Liste enthält aber keine Namen odr IDs von Videos, sondern nur, wie oft sie gesehen wurden,
# vie viele Likes und Dislikes sie bekommen haben (Summe), und welcher Prozentsatz davon auf Likes entfällt
#
# view_count,likes,ratio
# 8036001,324742,96.91
# 9378067,562589,98.19
# 2182066,273650,99.38
# 6525864,94698,96.25

# Einlesen mit dem CSV-Reader von Pandas
data = pd.read_csv(datasource)

# Wir verarbeiten alle drei Spalten
view_count = data['view_count']
likes = data['likes']
ratio = data['ratio']



# ===========================================================================================
# Erstellen des Streudiagramms
# ===========================================================================================

### Style
# plt.style.use("ggplot")
plt.style.use("seaborn")
# plt.style.use("fivethirtyeight")

# Das Streudiagramm
plt.scatter(view_count, likes, c = ratio, cmap = "summer", edgecolor = "black", linewidth = 1, alpha = 0.6)

# Farbbalken auf der Seite
cbar = plt.colorbar()
cbar.set_label("Prozent Likes")

# Logarithmische Skalierung auf beiden Achsen
plt.xscale("log")
plt.yscale("log")

# Titel
plt.title('Trendige YouTube Videos')

# Achsenbeschriftung
plt.xlabel('Anzahl Views')
plt.ylabel('Anzahl Likes + Dislikes')

# Layout-Variation
plt.tight_layout()

# Als Datei speichern
# plt.savefig("MatPlot.png")

# Als interaktive Grafik anzeigen
plt.show()
