#!/usr/bin/env python3


# ===========================================================================================
# Einbinden der Bibliotheken (Module)
# ===========================================================================================

# Allgemeines Modul für nummerische Berechnungen, siehe https://numpy.org
import numpy as np

# Modul, das zur Herstellung von Grafiken verwendet wird, siehe https://matplotlib.org
from matplotlib import pyplot as plt

# Interaktiver Cursor für Mathplotlib
import mplcursors


# ===========================================================================================
# Vorarbeit
# ===========================================================================================

# Zufallszahlengenerator initialisieren (damit bei jedem Aufruf dieselben Zahlen erzeugt werden)
# np.random.seed(42)


# ===========================================================================================
# Erstellen der Grafik
# ===========================================================================================

# Die etwas aufwändigere Art ein Matplotlib-Diagramm zu machen
fig, ax = plt.subplots()

# Scatterplot mit 26 zufälligen 2-dimensionalen Punkten
ax.scatter(*np.random.random((2, 26)))

# Titel
ax.set_title("Bewege den Mauszeiger über einen Punkt")

# Einen Cursor aktivieren
crs = mplcursors.cursor(ax,hover=True)

# Eine Annotation an den Punkt binden wenn der Mauszeiger den Punkt erreicht
crs.connect("add", lambda sel: sel.annotation.set_text('Punkt {0:5.3f},{1:5.3f}'.format(sel.target[0], sel.target[1])))

# Als interaktive Grafik anzeigen
plt.show()
