#!/usr/bin/env python3


# ===========================================================================================
# Einbinden der Bibliotheken (Module)
# ===========================================================================================

# Modul, das zur Herstellung von Grafiken verwendet wird, siehe https://matplotlib.org
from matplotlib import pyplot as plt

# Interaktiver Cursor für Mathplotlib
import mplcursors


# ===========================================================================================
# Bereitstellen der Daten
# ===========================================================================================

# 10 Punkte im dreidimensionalen Raum
x = [1,2,3,4,5,6,7,8,9,10]
y = [5,6,2,3,9,4,1,2,4,8]
z = [2,3,3,3,3,4,9,11,9,10]
# Jeder Punkt bekommt noch einen Namen
labels = list('abcdefghij')


# ===========================================================================================
# Erstellen der Grafik
# ===========================================================================================

# Matplotlib sagen, dass es eine 3D-Grafik machen soll
fig = plt.figure()
ax = fig.add_subplot(111,projection='3d')

# 3D-Scatterplot
ax.scatter(x,y,z)

# Achsenbeschriftungen
ax.set_xlabel('X Label')
ax.set_ylabel('Y Label')
ax.set_zlabel('Z Label')

# Einen Daten-Cursor aktivieren
crs = mplcursors.cursor(ax,hover=True)

# Eine Annotation an den Punkt binden wenn der Mauszeiger den Punkt erreicht
crs.connect("add", lambda sel: sel.annotation.set_text(labels[sel.target.index]))

# Als interaktive Grafik anzeigen
plt.show()


