#!/usr/bin/env python3


# ===========================================================================================
# Einbinden der Bibliotheken (Module)
# ===========================================================================================

# Modul, das zur Herstellung von Grafiken verwendet wird, siehe https://matplotlib.org
from matplotlib import pyplot as plt

# Die Bibliothek pandas (von PANel DAta) ist darauf spezialisiert Paneldaten zu verarbeiten,
# also zweidimensionale Tabellen (häufig Zeitreihen).
# In diesem Programm wird von dieser Bibliothek aber nur der CSV-Reader verwendet 
# siehe: https://pandas.pydata.org
import pandas as pd


# =========================================================================================== 
# Daten einlesen und aufbereiten
# =========================================================================================== 

# Wo stehen die Daten?
datasource = 'Daten/salery_per_age.csv'

# Immer wichtig zu wissen: Was steht das in den Daten?
#
# Gehälter von Softwareentwicklern pro Alter. Gemittelt über alle Sprachen,
# nur Python-Entwickler und nur Javascript-Entwickler
#
# die ersten Zeilen der Datei sehen so aus:
#
# Age,All_Devs,Python,JavaScript
# 18,17784,20046,16446
# 19,16500,17100,16791
# 20,18012,20000,18942
# 21,20628,24744,21780

# Einlesen mit dem CSV-Reader von Pandas
data = pd.read_csv(datasource)

# Daten für die X-Achse: Alter
ages = data['Age']

# Die Werte aus den drei Gehalts-Spalten
al_salaries = data['All_Devs']
py_salaries = data['Python']
js_salaries = data['JavaScript']


# =========================================================================================== 
# mehrteiliges Diagramm erzeugen
# =========================================================================================== 

### Style
# plt.style.use("ggplot")
plt.style.use("seaborn")
# plt.style.use("fivethirtyeight")

# Ein Diagramm (fig) mit zwei Subdiagrammen (ax1, ax2) erzeugen
# sharex = True: Die beiden verwenden eine gemeinsame X-Achse
fig, (ax1, ax2) = plt.subplots(nrows = 2, ncols = 1, sharex = True)

# erstes Fenster
# Liniendiagramm
ax1.plot(ages, al_salaries, color = '#444444', linestyle = '--', label = 'Alle Entwickler')

# Legende hinzufügen
ax1.legend()

# Titel
ax1.set_title('Durchschnittsgehälter pro Alter')

# Nur die Y-Achse beschriften
ax1.set_ylabel('Durchschnittsgehalt')

# zweites Fenster
# Zwei Liniendiagramme
ax2.plot(ages, py_salaries, label = 'Python')
ax2.plot(ages, js_salaries, label = 'JavaScript')

# Legende
ax2.legend()

# Kein Titel (steht schon im ersten Fenster)
# Dafür aber beide Achsen beschriften

ax2.set_xlabel('Alter')
ax2.set_ylabel('Durchschnittsgehalt')

# Layout-Variation
plt.tight_layout()

# Als Datei speichern
# plt.savefig("MatPlot.png")

# Als interaktive Grafik anzeigen
plt.show()
