#!/usr/bin/env python3


# ===========================================================================================
# Einbinden der Bibliotheken (Module)
# ===========================================================================================

# Das Modul csv vereinfacht das Lesen und Schreiben von csv-Dateien
# https://docs.python.org/3/library/csv.html
import csv

# Das Modul random stellt einen Zufallszahlengenerator zur Verfügung
# https://docs.python.org/3/library/random.html
import random

# Time enthält Funktionen für Zeitmessung, Timer usw.
# https://docs.python.org/3/library/time.html
import time


# ===========================================================================================
# Initialisierungen
# ===========================================================================================

# Name der Datei, in welche die hier erzeugten Daten geschrieben werden
csvFile = 'Daten/growingList.csv'

# Anfangswerte für die Zeitreihe festlegen
x_value = 0
total_1 = 1000
total_2 = 1000

# Spaltennamen definieren
fieldnames = ["x_value", "total_1", "total_2"]

# Spaltennamen in die csv-Datei schreiben
# Datei zum Schreiben öffnen
with open(csvFile, 'w') as csv_file:
    # Einen csv-Writer erzeugen
    csv_writer = csv.DictWriter(csv_file, fieldnames=fieldnames)
    # Die Feldnamen ausgeben
    csv_writer.writeheader()
# Die Datei wird am Ende des with-Blocks automatisch geschlossen


# ===========================================================================================
# ewige Schleife, die jede Sekunde eine neue Zeile zur csv-Datei hinzufügt
# ===========================================================================================

# für immer und ewig (bis man das Programm durch einen Interrupt abwürgt)
while True:

    # Datei zum Schreiben öffnen
    with open(csvFile, 'a') as csv_file:
        # Einen csv-Writer erzeugen
        csv_writer = csv.DictWriter(csv_file, fieldnames=fieldnames)

        # Die aktuell gültigen Werte zusammenstellen
        row = {
            "x_value": x_value,
            "total_1": total_1,
            "total_2": total_2
        }

        # Die Zeile in die csv-Datei schreiben
        csv_writer.writerow(row)
    # Die Datei wird am Ende des with-Blocks automatisch geschlossen

    # Zur Kontrolle dieselben Werte auch auf der Konsole ausgeben
    print(x_value, total_1, total_2)

    # Die Werte verändern
    x_value += 1
    total_1 = total_1 + random.randint(-6, 8)
    total_2 = total_2 + random.randint(-5, 6)

    # Den Prozess pausieren und das Betriebssystem bitten, den Prozess
    # nach einer Sekunde wieder weiter zu bearbeiten
    time.sleep(1)


