#!/usr/bin/env python3


# ===========================================================================================
# Einbinden der Bibliotheken (Module)
# ===========================================================================================

# Modul, das zur Herstellung von Grafiken verwendet wird, siehe https://matplotlib.org
from matplotlib import pyplot as plt

# Die Bibliothek pandas (von PANel DAta) ist darauf spezialisiert Paneldaten zu verarbeiten,
# also zweidimensionale Tabellen (häufig Zeitreihen).
# In diesem Programm wird von dieser Bibliothek aber nur der CSV-Reader verwendet 
# siehe: https://pandas.pydata.org
import pandas as pd

# Aus Mathplotlib brauchen wir auch noch die Animations-Funktion, die
# beim "normalen" Import nicht geladen wird
# https://matplotlib.org/3.3.3/api/animation_api.html
from matplotlib.animation import FuncAnimation


# ===========================================================================================
# Vorbereitungen
# ===========================================================================================

# Wo stehen die Daten?
datasource = 'Daten/growingList.csv'

# Ein leeres Diagramm erzeugen
# Stil festlegen
plt.style.use('fivethirtyeight')
# Die beiden Linienplots mit Defaultwerten und ohne Daten erzeugen
plt.plot([], [], label='Channel 1')
plt.plot([], [], label='Channel 2')

# Legende anzeigen
plt.legend()

# Layoutmodifikation
plt.tight_layout()


# ===========================================================================================
# Die Definition der Animations-Funktion
# ===========================================================================================
def animate(i):
    """Diese Funktion wird einmal pro Sekunde aufgerufen"""

    # Daten einlesen
    data = pd.read_csv(datasource)

    # Spalten auswählen
    x  = data['x_value']
    y1 = data['total_1']
    y2 = data['total_2']

    # Die beiden Linien auswählen
    ax = plt.gca()
    line1, line2 = ax.lines

    # Die alten Daten durch die neuen ersetzen
    line1.set_data(x, y1)
    line2.set_data(x, y2)

    # Position des linken Randes einer Linie auslesen
    # xlim_high brauchen wir eigentlich auch nicht, bekommen wir aber zwangsweise mitgeliefert
    xlim_low, xlim_high = ax.get_xlim()

    # X-Achse neu skalieren (rechts 5 Einheiten Platz lassen)
    ax.set_xlim(xlim_low, (x.max() + 5))

    # Minimum und Maximum der Y-Werte ermitteln
    y1max = y1.max()
    y2max = y2.max()
    current_ymax = y1max if (y1max > y2max) else y2max

    y1min = y1.min()
    y2min = y2.min()
    current_ymin = y1min if (y1min < y2min) else y2min

    # Y-Achse neu skalieren
    ax.set_ylim((current_ymin - 5), (current_ymax + 5))


# ===========================================================================================
# Ständig wiederholtes Ausführen der Animations-Funktion
# ===========================================================================================
ani = FuncAnimation(plt.gcf(), animate, interval=1000)

plt.show()
