#!/usr/bin/env python3


# ===========================================================================================
# Einbinden der Bibliotheken (Module)
# ===========================================================================================

# Allgemeines Modul für nummerische Berechnungen, siehe https://numpy.org
import numpy as np

# Modul, das zur Herstellung von Grafiken verwendet wird, siehe https://matplotlib.org
from matplotlib import pyplot as plt

# Die Bibliothek pandas (von PANel DAta) ist darauf spezialisiert Paneldaten zu verarbeiten,
# also zweidimensionale Tabellen (häufig Zeitreihen).
# In diesem Programm wird von dieser Bibliothek aber nur der CSV-Reader verwendet 
# siehe: https://pandas.pydata.org
import pandas as pd


# ===========================================================================================
# Daten einlesen und aufbereiten
# ===========================================================================================

# Wo stehen die Daten?
datasource = 'Daten/people.csv'

# gender,weight,size
# 8036001,324742,96.91
# 9378067,562589,98.19
# 2182066,273650,99.38
# 6525864,94698,96.25

# Einlesen mit dem CSV-Reader von Pandas
data = pd.read_csv(datasource)

# Wir verarbeiten alle drei Spalten
gender = data['gender']
weight = data['weight']
size   = data['size']

# Die Daten für Männer und Frauen in separate Dateien geben
weightF = []
sizeF   = []
weightM = []
sizeM   = []
for i in range(len(gender)):
	if gender[i] == 'F':
		weightF.append(weight[i])
		sizeF.append(size[i])
	if gender[i] == 'M':
		weightM.append(weight[i])
		sizeM.append(size[i])

# polyfit = Least squares polynomial fit
# Die Funktion polyfit berechnet Achsenabschnitt und Steigung der Ausgleichsgeraden
# https://numpy.org/doc/stable/reference/generated/numpy.polyfit.html
# Die Funktion poly1d macht aus diesen Koeffizienen ein Polynom, in diesem Fall
# also eine Gerade
# https://numpy.org/doc/stable/reference/generated/numpy.poly1d.html
Gerade  = np.poly1d(np.polyfit(size, weight, deg=1))
GeradeF = np.poly1d(np.polyfit(sizeF,weightF,deg=1))
GeradeM = np.poly1d(np.polyfit(sizeM,weightM,deg=1))


# ===========================================================================================
# Erstellen des Streudiagramms
# ===========================================================================================

### Style
# plt.style.use("ggplot")
plt.style.use("seaborn")
# plt.style.use("fivethirtyeight")

# Das Streudiagramm
plt.scatter(sizeF, weightF, color = 'red',  edgecolor = "black", linewidth = 1, alpha = 0.6)
plt.scatter(sizeM, weightM, color = 'blue', edgecolor = "black", linewidth = 1, alpha = 0.6)
plt.plot(size,  Gerade(size),   color='black', alpha=0.5)
plt.plot(sizeF, GeradeF(sizeF), color='red',   alpha=0.5)
plt.plot(sizeM, GeradeM(sizeM), color='blue',  alpha=0.5)

# Achsenbeschriftung
plt.xlabel('Größe')
plt.ylabel('Gewicht')

# Layout-Variation
plt.tight_layout()

# Als Datei speichern
# plt.savefig("MatPlot.png")

# Als interaktive Grafik anzeigen
plt.show()
